@@ -14,6 +14,7 @@ from dataclasses import dataclass
 from rich.console import Console
 from .config import AIConfig, AIModelConfig
 from .validators import ResponseValidator
+from .function_call import function_registry
 
 # 创建console实例用于调试日志
 console = Console(markup=False)
@@ -180,6 +181,26 @@ class AIClient:
             if parsed:
                 tool_calls = parsed
         
+        # 清理文本中的工具标记块，避免展示污染
+        try:
+            import re
+            t = content or ""
+            t = t.replace("｜", "|").replace("▁", "_")
+            patterns = [
+                r"<\|\s*tool[\s_]*calls[\s_]*begin\s*\|>",
+                r"<\|\s*tool[\s_]*calls[\s_]*end\s*\|>",
+                r"\|\s*<\s*tool[\s_]*calls[\s_]*begin\s*>\s*\|",
+                r"\|\s*<\s*tool[\s_]*calls[\s_]*end\s*>\s*\|",
+            ]
+            for p in patterns:
+                t = re.sub(p, "", t, flags=re.IGNORECASE)
+            # 移除工具调用块内容
+            t = re.sub(r"<\|\s*tool\s*_call\s*_begin\s*\|>.*?<\|\s*tool\s*_call\s*_end\s*\|>", "", t, flags=re.DOTALL | re.IGNORECASE)
+            t = re.sub(r"\|\s*<\s*tool\s*_call[\s_]*begin\s*>\s*\|.*?\|\s*<\s*tool\s*_call[\s_]*end\s*>\s*\|", "", t, flags=re.DOTALL | re.IGNORECASE)
+            content = t.strip()
+        except Exception:
+            pass
+        
         return AIResponse(
             content=content,
             raw_response=data,
@@ -214,75 +235,224 @@ class AIClient:
         """从文本内容中解析工具调用
 
         支持两类文本格式：
-        1) 直接函数调用格式：smart_search({"repo": "logs", "query": "*"})
-        2) 标记格式：<|tool_calls_begin|><|tool_call_begin|> function_name <|tool_sep|> {json} <|tool_call_end|><|tool_calls_end|>
+        1) 直接函数调用格式：fn({json})
+        2) 标记格式：<|tool_call_begin|> fn <|tool_sep|> {json} <|tool_call_end|>
+        设计划重点：
+        - 通用、无方法名特例：仅做格式统一与类型泛化
+        - 名称归一：驼峰→下划线、分隔符→下划线、小写
+        - 参数键归一与类型泛化：按注册schema将键归一、类型转换、补足必填
         """
         import re
+        import json
 
         if not content:
             return None
 
+        # 标记归一：全角竖线 → ASCII 竖线，特殊下划线符号“ ” → "_"；
+        # 同时去除无用的外层 <|tool_calls_begin|> / <|tool_calls_end|>
+        def _normalize_markers(text: str) -> str:
+            try:
+                t = text or ""
+            except Exception:
+                return text
+            t = t.replace("｜", "|")
+            t = t.replace("▁", "_")
+            # 去除外层 calls 包裹以降低正则复杂度（兼容多种写法与空格/下划线混用）
+            patterns = [
+                r"<\|\s*tool[\s_]*calls[\s_]*begin\s*\|>",
+                r"<\|\s*tool[\s_]*calls[\s_]*end\s*\|>",
+                r"\|\s*<\s*tool[\s_]*calls[\s_]*begin\s*>\s*\|",
+                r"\|\s*<\s*tool[\s_]*calls[\s_]*end\s*>\s*\|",
+            ]
+            for p in patterns:
+                t = re.sub(p, "", t, flags=re.IGNORECASE)
+            return t
+
+        content = _normalize_markers(content)
+
         tool_calls: List[Dict[str, Any]] = []
 
+        # 通用名称归一：驼峰→下划线；分隔符(., -, /, 空格)→下划线；小写；去重下划线
+        def _normalize_name(name: str) -> str:
+            try:
+                n = (name or "").strip()
+            except Exception:
+                n = ""
+            if not n:
+                return n
+            n = re.sub(r"([a-z0-9])([A-Z])", r"\1_\2", n)
+            n = re.sub(r"[\.\-/\s]+", "_", n)
+            n = n.lower()
+            n = re.sub(r"_+", "_", n).strip("_")
+            return n
+
+        # 通用键归一：对参数键应用与名称相同的归一策略
+        def _normalize_key(k: str) -> str:
+            return _normalize_name(k)
+
+        # 类型泛化与必填补足（基于函数schema，通用而非特定函数）
+        def _normalize_args(func: str, args: Any) -> Dict[str, Any]:
+            # 非字典统一包裹
+            if not isinstance(args, dict):
+                return {"value": args}
+            a = {}
+            for k, v in args.items():
+                a[_normalize_key(k)] = v
+
+            # 尝试获取函数schema
+            func_schema = None
+            try:
+                func_schema = function_registry.get_function(func)
+            except Exception:
+                func_schema = None
+
+            if not func_schema or not isinstance(func_schema.parameters, dict):
+                return a
+
+            params = func_schema.parameters or {}
+            props = params.get("properties", {}) or {}
+            required = params.get("required", []) or []
+
+            # 通用类型转换：依据schema类型将字符串转换为目标类型
+            def coerce_value(value: Any, typ: str) -> Any:
+                if typ == "boolean":
+                    if isinstance(value, bool):
+                        return value
+                    if isinstance(value, str):
+                        s = value.strip().lower()
+                        if s in {"true", "1", "yes", "y"}:
+                            return True
+                        if s in {"false", "0", "no", "n"}:
+                            return False
+                    if isinstance(value, (int, float)):
+                        return bool(value)
+                    return value
+                if typ == "integer":
+                    if isinstance(value, int):
+                        return value
+                    if isinstance(value, str):
+                        try:
+                            return int(value.strip())
+                        except Exception:
+                            return value
+                    if isinstance(value, float):
+                        return int(value)
+                    return value
+                if typ == "number":
+                    if isinstance(value, (int, float)):
+                        return float(value)
+                    if isinstance(value, str):
+                        try:
+                            return float(value.strip())
+                        except Exception:
+                            return value
+                    return value
+                if typ == "array":
+                    if isinstance(value, list):
+                        return value
+                    if isinstance(value, str):
+                        # 通用：逗号分隔视为数组；否则单值数组
+                        parts = [p.strip() for p in value.split(",")]
+                        parts = [p for p in parts if p]
+                        return parts if len(parts) > 1 else [value]
+                    return [value]
+                # 默认原样返回
+                return value
+
+            # 按schema转换已提供的属性类型
+            for k in list(a.keys()):
+                if k in props:
+                    typ = props.get(k, {}).get("type")
+                    if isinstance(typ, str):
+                        a[k] = coerce_value(a[k], typ)
+
+            # 补足必填：若缺失必填键，通用地从“未知键”中挑选类型匹配值赋入
+            missing = [rk for rk in required if rk not in a]
+            if missing:
+                # 候选：不在props中的键或已在props但类型不匹配的值
+                candidate_keys = [ck for ck in a.keys() if ck not in props]
+                # 若无候选，则不做补足
+                for rk in missing:
+                    rk_typ = props.get(rk, {}).get("type", "string")
+                    chosen_key = None
+                    # 先找类型严格匹配的候选
+                    for ck in candidate_keys:
+                        v = a.get(ck)
+                        vv = coerce_value(v, rk_typ)
+                        # 若转换结果类型合理（例如字符串转换仍为字符串、数字成功转换），则选用
+                        if rk_typ == "array" and isinstance(vv, list):
+                            chosen_key = ck
+                            break
+                        if rk_typ == "integer" and isinstance(vv, int):
+                            chosen_key = ck
+                            break
+                        if rk_typ == "number" and isinstance(vv, float):
+                            chosen_key = ck
+                            break
+                        if rk_typ == "boolean" and isinstance(vv, bool):
+                            chosen_key = ck
+                            break
+                        if rk_typ == "string" and isinstance(vv, str):
+                            # 对字符串，偏向较长文本（更可能是表达式/查询）
+                            chosen_key = ck if (chosen_key is None or len(str(v)) > len(str(a.get(chosen_key)))) else chosen_key
+                    # 若未找到严格匹配，以第一个候选兜底
+                    if chosen_key is None and candidate_keys:
+                        chosen_key = candidate_keys[0]
+                    # 执行赋值与移除候选键
+                    if chosen_key is not None:
+                        a[rk] = coerce_value(a[chosen_key], rk_typ)
+                        candidate_keys.remove(chosen_key)
+                        a.pop(chosen_key, None)
+
+            return a
+
         # 1) 解析“函数名(JSON)”样式
         func_pattern = r'(\w+)\s*\(\s*({[^}]+})\s*\)'
         func_matches = re.findall(func_pattern, content)
         for i, (function_name, args_str) in enumerate(func_matches):
             try:
-                import json
-                json.loads(args_str)  # 验证JSON
-                tool_calls.append({
-                    "id": f"call_{len(tool_calls)}_{function_name}",
-                    "type": "function",
-                    "function": {
-                        "name": function_name,
-                        "arguments": args_str
-                    }
-                })
+                args_obj = json.loads(args_str)
             except Exception:
                 continue
+            canonical = _normalize_name(function_name)
+            norm_args = _normalize_args(canonical, args_obj)
+            tool_calls.append({
+                "id": f"call_{len(tool_calls)}_{canonical}",
+                "type": "function",
+                "function": {
+                    "name": canonical,
+                    "arguments": json.dumps(norm_args, ensure_ascii=False)
+                }
+            })
 
         # 2) 解析“工具标记”样式
-        # 兼容多种分隔形式：<|tool_sep|> 或 |< tool_sep >|
         marker_block_pattern = r'<\|\s*tool_call_begin\s*\|>(.*?)<\|\s*tool_call_end\s*\|>'
         marker_blocks = re.findall(marker_block_pattern, content, flags=re.DOTALL)
         for block in marker_blocks:
-            # 按分隔符拆分函数名与参数
             parts = re.split(r'(?:<\|\s*tool_sep\s*\|>|\|\s*<\s*tool_sep\s*>\s*\|)', block, maxsplit=1)
             if len(parts) != 2:
                 continue
-            func_name = parts[0].strip().strip('|').strip()
+            func_name_raw = parts[0].strip().strip('|').strip()
             args_str = parts[1].strip()
-
-            # 去除可能的代码块包裹
             args_str = re.sub(r'^```[a-zA-Z0-9_\-]*\n', '', args_str)
-            args_str = re.sub(r'```\s*$', '', args_str)
-
-            # 尝试解析JSON参数，必要时做简单清理
-            import json
+            args_str = re.sub(r"```\s*$", '', args_str)
             try:
-                json.loads(args_str)
+                args_obj = json.loads(args_str)
             except json.JSONDecodeError:
-                # 宽松修复：单引号替换为双引号、去掉尾逗号
                 cleaned = args_str.replace("'", '"')
                 cleaned = re.sub(r',\s*}', '}', cleaned)
                 try:
-                    json.loads(cleaned)
-                    args_str = cleaned
+                    args_obj = json.loads(cleaned)
                 except json.JSONDecodeError:
                     continue
-
-            # 仅接受合法函数名
-            if not re.match(r'^[A-Za-z_][A-Za-z0-9_]*$', func_name):
-                continue
-                
-
+            canonical = _normalize_name(func_name_raw)
+            norm_args = _normalize_args(canonical, args_obj)
             tool_calls.append({
-                "id": f"call_{len(tool_calls)}_{func_name}",
+                "id": f"call_{len(tool_calls)}_{canonical}",
                 "type": "function",
                 "function": {
-                    "name": func_name,
-                    "arguments": args_str
+                    "name": canonical,
+                    "arguments": json.dumps(norm_args, ensure_ascii=False)
                 }
             })
 
@@ -317,6 +487,26 @@ class AIClient:
         if not tool_calls and content:
             tool_calls = self._parse_tool_calls_from_text(content)
         
+        # 清理文本中的工具标记块，避免展示污染
+        try:
+            import re
+            t = content or ""
+            t = t.replace("｜", "|").replace("▁", "_")
+            patterns = [
+                r"<\|\s*tool[\s_]*calls[\s_]*begin\s*\|>",
+                r"<\|\s*tool[\s_]*calls[\s_]*end\s*\|>",
+                r"\|\s*<\s*tool[\s_]*calls[\s_]*begin\s*>\s*\|",
+                r"\|\s*<\s*tool[\s_]*calls[\s_]*end\s*>\s*\|",
+            ]
+            for p in patterns:
+                t = re.sub(p, "", t, flags=re.IGNORECASE)
+            # 移除工具调用块内容
+            t = re.sub(r"<\|\s*tool\s*_call\s*_begin\s*\|>.*?<\|\s*tool\s*_call\s*_end\s*\|>", "", t, flags=re.DOTALL | re.IGNORECASE)
+            t = re.sub(r"\|\s*<\s*tool\s*_call[\s_]*begin\s*>\s*\|.*?\|\s*<\s*tool\s*_call[\s_]*end\s*>\s*\|", "", t, flags=re.DOTALL | re.IGNORECASE)
+            content = t.strip()
+        except Exception:
+            pass
+        
         return AIResponse(
             content=content,
             raw_response=data,
