@@ -21,6 +21,8 @@ class AIModelConfig:
     max_tokens: int = 4096
     temperature: float = 0.7
     timeout: int = 300
+    # 新增：工具迭代上限，默认20次
+    max_iterations: int = 20
     headers: Optional[Dict[str, str]] = None
     extra_params: Optional[Dict[str, Any]] = None
 
@@ -112,6 +114,7 @@ class AIConfig:
             max_tokens=config_data.get('max_tokens', 4096),
             temperature=config_data.get('temperature', 0.7),
             timeout=config_data.get('timeout', 30),
+            max_iterations=config_data.get('max_iterations', 20),
             headers=config_data.get('headers'),
             extra_params=config_data.get('extra_params')
         )
@@ -143,6 +146,7 @@ class AIConfig:
             'max_tokens': model_config.max_tokens,
             'temperature': model_config.temperature,
             'timeout': model_config.timeout,
+            'max_iterations': model_config.max_iterations,
             'headers': model_config.headers,
             'extra_params': model_config.extra_params
         }
