@@ -172,7 +172,7 @@ def search_data(spl: str, limit: int = 100, format_type: str = "csv", output_fil
             validate_spl_value_quotes(spl)
         except ValueError as ve:
             return str(ve)
-        return f"搜索失败: {str(se)}"
+        return f"搜索失败: {str(se)}, 请获取SPL语法参考文档以确认查询语句是否正确。"
 
     # 构造结果输出对象可能抛错（返回结构异常等），同样走校验兜底
     try:
@@ -286,12 +286,24 @@ def get_repo_fields(repository: str, limit: int = 10) -> str:
         # 构建SPL查询，将时间参数直接嵌入到查询中
         # 调用search_summary获取字段信息，不传递时间参数（因为已经在SPL中了）
         fields = list(search_summary(spl=get_fields_spl).keys())
-        
+        # return fields
         # 格式化返回结果
         field_values = {}
-        for field in fields[:limit]:
+        # 初始化计数器和有效字段计数器
+        n = 0
+        valid_fields_count = 0
+        
+        # 遍历所有字段
+        while n < len(fields) and valid_fields_count < limit:
+            field = fields[n]
+            n += 1
+            
+            # 跳过系统字段
             if field in ("_indexTime", "_time", "_raw", "_signature_id", "linenum", "repo"):
                 continue
+                
+            # 增加有效字段计数
+            valid_fields_count += 1
             get_fields_value_spl = f"""repo="{repository}"
 | where isNotNull('{field}')    
 | stats count() as countKey1 by '{field}' with count() as total, distinct('{field}', 0) as distinct
@@ -308,7 +320,9 @@ def get_repo_fields(repository: str, limit: int = 10) -> str:
         
         result = {
             "repository": repository,
-            "fields": field_values
+            "fields": field_values,
+            "total_fields": len(fields),
+            "return_fields": limit
         }
         
         text = json.dumps(result, ensure_ascii=False, indent=2)
