@@ -308,7 +308,7 @@ class ChatChartWidget(Static):
                         title_text = title_text[:max_len] + "..."
                     plot_widget.plt.title(title_text)
             except Exception:
-                self.notify("图表标题设置失败")
+                self.notify("图表标题设置失败", severity="error")
             plot_widget.refresh()
         except Exception as e:
             content.remove_children()
