@@ -129,7 +129,7 @@ def request(method, path, data=None, query_params=None, custom_headers=None, _gz
         raise Exception(f"Invalid method: {method}")
 
     if isinstance(data, (dict, list)):
-        data = json.dumps(data)
+        data = json.dumps(data, ensure_ascii=False)
     if _gzip:
         data = gzip.compress(data.encode('utf-8'))
     
