@@ -465,6 +465,7 @@ class ModelConfigManagerWidget(Container):
             yield Label("模型配置管理", classes="header-title")
         
         with Horizontal(id="config_toolbar"):
+            yield Button("返回", variant="default", id="return_button", classes="toolbar-button")
             yield Button("新增", variant="primary", id="add_button", classes="toolbar-button")
             yield Button("编辑", variant="default", id="edit_button", classes="toolbar-button")
             yield Button("删除", variant="error", id="delete_button", classes="toolbar-button")
@@ -484,6 +485,11 @@ class ModelConfigManagerWidget(Container):
         table = self.query_one("#config_table", ModelConfigTable)
         table.refresh_data()
     
+    @on(Button.Pressed, "#return_button")
+    def on_return_button_pressed(self, event: Button.Pressed) -> None:
+        """返回按钮点击事件"""
+        self.app.pop_screen()
+    
     @on(Button.Pressed, "#add_button")
     def on_add_button_pressed(self, event: Button.Pressed) -> None:
         """新增按钮点击事件"""
@@ -594,4 +600,4 @@ class ModelConfigManagerWidget(Container):
     def on_config_tested(self, event: ModelConfigModal.ConfigTested) -> None:
         """处理配置测试事件"""
         # TODO: 实现配置测试逻辑
-        self.app.notify("配置测试功能待实现", severity="info")
\ No newline at end of file
+        self.app.notify("配置测试功能待实现", severity="warning")
\ No newline at end of file
