@@ -8,6 +8,7 @@ from textual.message import Message
 from textual.screen import ModalScreen
 from textual.widgets import Button, Label, Static, Checkbox, Collapsible
 import logging
+import pyperclip
 
 from ..data_models import ChatSession, SessionManager
 
@@ -154,12 +155,17 @@ class ContextWindowModal(ModalScreen):
     仅展示用户与模型的对话内容。
     """
 
+    def __init__(self, **kwargs):
+        super().__init__(**kwargs)
+        self._copy_text = ""
+
     def compose(self) -> ComposeResult:
         with Container(id="context-modal", classes="context-modal"):
             with Vertical(classes="context-content"):
                 yield Label("上下文窗口", classes="modal-title")
                 yield ScrollableContainer(classes="context-sections", id="context-content")
                 with Horizontal(classes="modal-buttons"):
+                    yield Button("复制全部", id="copy-button", variant="primary")
                     yield Button("关闭", id="close-button", variant="default")
 
     def on_mount(self) -> None:
@@ -175,6 +181,7 @@ class ContextWindowModal(ModalScreen):
 
         if not conv_messages:
             content.mount(Static("暂无对话内容", classes="empty-message", markup=False))
+            self._copy_text = ""
             return
 
         # 准备要显示的内容行
@@ -204,10 +211,23 @@ class ContextWindowModal(ModalScreen):
         if prepared_lines:
             prepared_block = Static("\n".join(prepared_lines), classes="context-block", markup=False)
             content.mount(prepared_block)
+            self._copy_text = "\n".join(prepared_lines)
 
     def on_button_pressed(self, event: Button.Pressed) -> None:
         if event.button.id == "close-button":
             self.dismiss()
+        elif event.button.id == "copy-button":
+            try:
+                if not self._copy_text:
+                    self.app.notify("暂无可复制的对话内容", severity="warning")
+                    return
+                pyperclip.copy(self._copy_text)
+                self.app.notify("已复制全部对话内容到剪贴板", severity="success")
+            except Exception as e:
+                try:
+                    self.app.notify(f"复制失败: {str(e)}", severity="error")
+                except Exception:
+                    pass
 
 
 class SessionHistoryModal(ModalScreen):
@@ -303,7 +323,25 @@ class SessionHistoryModal(ModalScreen):
             # 触发会话选择
             self.post_message(self.SessionSelected(focused_widget.session))
             self.dismiss()
-    
+
+    def on_key(self, event) -> None:
+        """处理键盘事件"""
+        if event.key == "up":
+            self._navigate_sessions(-1)
+            event.prevent_default()
+        elif event.key == "down":
+            self._navigate_sessions(1)
+            event.prevent_default()
+        elif event.key == "enter":
+            self._select_focused_session()
+            event.prevent_default()
+        elif event.key == "delete" or event.key == "d":
+            self._delete_focused_session()
+            event.prevent_default()
+        elif event.key == "escape":
+            self.dismiss()
+            event.prevent_default()
+
     def _load_sessions(self):
         """加载历史会话列表"""
         session_list = self.query_one("#session-list", ScrollableContainer)
@@ -327,7 +365,49 @@ class SessionHistoryModal(ModalScreen):
         for session in self.sessions:
             session_widget = SessionItemWidget(session)
             session_list.mount(session_widget)
-    
+
+    def _navigate_sessions(self, direction: int):
+        """在会话列表中导航"""
+        session_list = self.query_one("#session-list", ScrollableContainer)
+        items = [w for w in session_list.children if isinstance(w, SessionItemWidget)]
+        if not items:
+            return
+        focused = None
+        for idx, item in enumerate(items):
+            if item.has_class("focused"):
+                focused = idx
+                break
+        if focused is None:
+            items[0].focus()
+            items[0].add_class("focused")
+            return
+        new_idx = max(0, min(len(items) - 1, focused + direction))
+        if new_idx != focused:
+            items[focused].remove_class("focused")
+            items[new_idx].focus()
+            items[new_idx].add_class("focused")
+
+    def _select_focused_session(self):
+        """选择当前焦点的会话"""
+        focused_widget = self.focused
+        if isinstance(focused_widget, SessionItemWidget):
+            # 触发会话选择
+            self.post_message(self.SessionSelected(focused_widget.session))
+            self.dismiss()
+
+    def _delete_focused_session(self):
+        """删除当前焦点的会话"""
+        focused_widget = self.focused
+        if isinstance(focused_widget, SessionItemWidget):
+            try:
+                self.session_manager.delete_session(focused_widget.session.id)
+                focused_widget.remove()
+            except Exception as e:
+                try:
+                    self.app.notify(f"删除失败: {str(e)}", severity="error")
+                except Exception:
+                    pass
+
     def on_session_item_widget_session_clicked(self, message) -> None:
         """处理会话项点击事件"""
         self.post_message(self.SessionSelected(message.session))
@@ -388,7 +468,7 @@ class SessionItemWidget(Static):
         super().__init__(**kwargs)
         self.session = session
         self.last_click_time = 0
-    
+
     def compose(self) -> ComposeResult:
         """构建会话项UI"""
         title = self.session.get_display_title()
@@ -412,7 +492,7 @@ class SessionItemWidget(Static):
             self.post_message(self.SessionClicked(self.session))
         
         self.last_click_time = current_time
-    
+
     def on_key(self, event) -> None:
         """处理键盘事件"""
         if event.key == "enter":
